"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-explicit-any */
const schematics_1 = require("@angular-devkit/schematics");
const workspace_1 = require("@nrwl/workspace");
const path = require("path");
function getTsconfigFilePaths(host) {
    const tsconfigFilePaths = [];
    const tsconfigE2eFilePaths = [];
    const workspaceJson = (0, workspace_1.readJsonInTree)(host, 'workspace.json');
    Object.values(workspaceJson.projects).forEach((project) => {
        Object.values(project.architect).forEach((target) => {
            var _a;
            if (((_a = target.options) === null || _a === void 0 ? void 0 : _a.webpackConfig) !== '@nxext/ionic-react/plugins/webpack') {
                return;
            }
            const e2eProjectName = Object.keys(workspaceJson.projects).find((key) => workspaceJson.projects[key] === project);
            const e2eProject = workspaceJson.projects[`${e2eProjectName}-e2e`];
            if (host.exists(`${e2eProject.root}/tsconfig.e2e.json`) &&
                host.exists(`${e2eProject.root}/tsconfig.json`)) {
                tsconfigFilePaths.push(path.join(e2eProject.root, 'tsconfig.json'));
                tsconfigE2eFilePaths.push(`${e2eProject.root}/tsconfig.e2e.json`);
            }
        });
    });
    return { tsconfigFilePaths, tsconfigE2eFilePaths };
}
function updateTsconfigFilePaths(tsconfigFilePaths) {
    const rules = [];
    tsconfigFilePaths.forEach((tsconfigFilePath) => {
        rules.push((0, workspace_1.updateJsonInTree)(tsconfigFilePath, (json) => {
            var _a;
            if ((_a = json.compilerOptions) === null || _a === void 0 ? void 0 : _a.types) {
                const index = json.compilerOptions.types.indexOf('@types/testing-library__cypress');
                if (index !== -1) {
                    json.compilerOptions.types.splice(index, 1);
                }
            }
            return json;
        }));
    });
    return rules;
}
function updateTsconfigE2eFilePaths(tsconfigE2eFilePaths) {
    const rules = [];
    tsconfigE2eFilePaths.forEach((tsconfigFilePath) => {
        rules.push((0, workspace_1.updateJsonInTree)(tsconfigFilePath, (json) => {
            if (!json.compilerOptions) {
                json.compilerOptions = {};
            }
            if (!json.compilerOptions.types) {
                json.compilerOptions.types = [];
            }
            json.compilerOptions.types.push('@testing-library/cypress');
            return json;
        }));
    });
    return rules;
}
function updateCypressTsconfigTypes() {
    return (host) => {
        let rules = [];
        const { devDependencies } = (0, workspace_1.readJsonInTree)(host, 'package.json');
        if (devDependencies && devDependencies['@nxext/ionic-react']) {
            const { tsconfigFilePaths, tsconfigE2eFilePaths } = getTsconfigFilePaths(host);
            rules = updateTsconfigFilePaths(tsconfigFilePaths);
            rules = [...rules, ...updateTsconfigE2eFilePaths(tsconfigE2eFilePaths)];
        }
        return (0, schematics_1.chain)(rules);
    };
}
function update() {
    return (0, schematics_1.chain)([updateCypressTsconfigTypes(), (0, workspace_1.formatFiles)()]);
}
exports.default = update;
//# sourceMappingURL=update-testing-library-cypress-tsconfig-types-3-1-0.js.map